#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""This module adds a menu item to the nautilus right-click menu which allows to add 
   all the selected files to the Audacious Playlist just through the right-clicking"""

#   add-to-audacious-playlist2.py version 1.0.6
#   
#   Copyright 2008-2010 Giuseppe Penone <giuspen@gmail.com>
#    
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#    
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#    
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#   MA 02110-1301, USA.

import pygtk
pygtk.require('2.0')
import gtk
import nautilus, gconf, urllib, os, sys, subprocess, re
import locale, gettext

APP_NAME = "nautilus-pyextensions"
LOCALE_PATH = '/usr/share/locale/'
# internationalization
locale.setlocale(locale.LC_ALL, '')
gettext.bindtextdomain(APP_NAME, LOCALE_PATH)
gettext.textdomain(APP_NAME)
_ = gettext.gettext
# post internationalization code starts here
NAUTILUS_MENU_LABEL = _('Add To Audacious2 Playlist')
NAUTILUS_MENU_HELP = _('Add the selected Audio file(s) to the Audacious2 Playlist')


def error_dialog(message, dialog_title = _("Error...")):
   """The extension's error dialog"""
   dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
                              type=gtk.MESSAGE_ERROR,
                              buttons=gtk.BUTTONS_OK,
                              message_format=message)
   dialog.set_title(dialog_title)
   dialog.run()
   dialog.destroy()

class AddToAudaciousPlaylist(nautilus.MenuProvider):
   """Implements the 'Add To Audacious Playlist' extension to the nautilus right-click menu"""
   
   def __init__(self):
      """Creates a GConfClient (Gnome Configuration Client)"""
      self.client = gconf.client_get_default()
   
   def run(self, menu, source_path_list):
      """Runs the Adding of selected Audio file(s) to the Audacious Playlist"""
      try: subprocess.call("audacious2 -e " + " ".join(source_path_list) + " &", shell=True)
      except: error_dialog("Exception Error:\n%s" % sys.exc_info())
   
   def get_file_items(self, window, sel_items):
      """Adds the 'Add To Audacious Playlist' menu item to the Nautilus right-click menu, 
         connects its 'activate' signal to the 'run' method passing the list of selected Audio items"""
      if sel_items[0].is_directory() or sel_items[0].get_uri_scheme() != 'file':
         return
      source_path_list = []
      for sel_item in sel_items:
         source_path = re.escape(urllib.unquote(sel_item.get_uri()[7:]))
         filetype = subprocess.Popen("file -i %s" % source_path, shell=True, stdout=subprocess.PIPE).communicate()[0]
         if "audio" in filetype: source_path_list.append(source_path)
      if source_path_list:
         item = nautilus.MenuItem('NautilusPython::audacious', NAUTILUS_MENU_LABEL, NAUTILUS_MENU_HELP)
         item.set_property('icon', 'audacious')
         item.connect('activate', self.run, source_path_list)
         return item,
